==> haskell-test-framework-0.8.1.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework
version: 0.8.1.1
id: test-framework-0.8.1.1-KC8oChssjbiIyg7PdNxvLN
key: test-framework-0.8.1.1-KC8oChssjbiIyg7PdNxvLN
license: BSD3
maintainer: Libraries List <libraries@haskell.org>
homepage: https://batterseapower.github.io/test-framework/
synopsis: Framework for running and organising tests, with HUnit and QuickCheck support
description:
    Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
    parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
    command line options. All of this comes with colored test output, progress reporting and test statistics output.
category: Testing
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
exposed-modules:
    Test.Framework Test.Framework.Options Test.Framework.Providers.API
    Test.Framework.Runners.Console Test.Framework.Runners.Options
    Test.Framework.Runners.TestPattern Test.Framework.Runners.API
    Test.Framework.Seed
hidden-modules: Test.Framework.Core Test.Framework.Improving
                Test.Framework.Runners.Console.Colors
                Test.Framework.Runners.Console.ProgressBar
                Test.Framework.Runners.Console.Run
                Test.Framework.Runners.Console.Statistics
                Test.Framework.Runners.Console.Table
                Test.Framework.Runners.Console.Utilities
                Test.Framework.Runners.Core Test.Framework.Runners.Processors
                Test.Framework.Runners.Statistics Test.Framework.Runners.ThreadPool
                Test.Framework.Runners.TimedConsumption
                Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
                Test.Framework.Utilities
abi: 9b046aa456c9f3123556569ea60063d7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/test-framework-0.8.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/test-framework-0.8.1.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/test-framework-0.8.1.1
hs-libraries: HStest-framework-0.8.1.1-KC8oChssjbiIyg7PdNxvLN
depends:
    ansi-terminal-0.6.2.3-AKTYR0nthhUCHW4HMZvJFX
    ansi-wl-pprint-0.6.7.3-BxXaXM4de7bF6SGXMvMtbC base-4.9.0.0
    containers-0.5.7.1 hostname-1.0-42Ipmmd3lMbCN35rV9k5gh
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    random-1.1-54KmMHXjttlERYcr1mvsAe
    regex-posix-0.95.2-Fy6xYMm8dnjHHt23b8RdmR time-1.6.0.1
    xml-1.3.14-rYbwgRBahsKh5Xn1LyTeP
haddock-interfaces: /usr/share/doc/haskell-test-framework/html/test-framework.haddock
haddock-html: /usr/share/doc/haskell-test-framework/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-0.8.1.1-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework
version: 0.8.1.1
id: test-framework-0.8.1.1-jVXPZTswcZDeN85OGIrlV
key: test-framework-0.8.1.1-jVXPZTswcZDeN85OGIrlV
license: BSD3
maintainer: Libraries List <libraries@haskell.org>
homepage: https://batterseapower.github.io/test-framework/
synopsis: Framework for running and organising tests, with HUnit and QuickCheck support
description:
    Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
    parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
    command line options. All of this comes with colored test output, progress reporting and test statistics output.
category: Testing
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
exposed-modules:
    Test.Framework Test.Framework.Options Test.Framework.Providers.API
    Test.Framework.Runners.Console Test.Framework.Runners.Options
    Test.Framework.Runners.TestPattern Test.Framework.Runners.API
    Test.Framework.Seed
hidden-modules: Test.Framework.Core Test.Framework.Improving
                Test.Framework.Runners.Console.Colors
                Test.Framework.Runners.Console.ProgressBar
                Test.Framework.Runners.Console.Run
                Test.Framework.Runners.Console.Statistics
                Test.Framework.Runners.Console.Table
                Test.Framework.Runners.Console.Utilities
                Test.Framework.Runners.Core Test.Framework.Runners.Processors
                Test.Framework.Runners.Statistics Test.Framework.Runners.ThreadPool
                Test.Framework.Runners.TimedConsumption
                Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
                Test.Framework.Utilities
abi: 93a980afd4a63e4c9d63b3a0ceef9312
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/test-framework-0.8.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/test-framework-0.8.1.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/test-framework-0.8.1.1
hs-libraries: HStest-framework-0.8.1.1-jVXPZTswcZDeN85OGIrlV
depends:
    ansi-terminal-0.6.3.1-C5gpy392zkR1qCeRuDySE4
    ansi-wl-pprint-0.6.7.3-6GCcsFDbx2V8PibFjHfpG5 base-4.9.0.0
    containers-0.5.7.1 hostname-1.0-42Ipmmd3lMbCN35rV9k5gh
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    random-1.1-54KmMHXjttlERYcr1mvsAe
    regex-posix-0.95.2-Fy6xYMm8dnjHHt23b8RdmR time-1.6.0.1
    xml-1.3.14-9IpHbL0QRqR5eAZpdkwTMQ
haddock-interfaces: /usr/share/doc/haskell-test-framework/html/test-framework.haddock
haddock-html: /usr/share/doc/haskell-test-framework/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
